@@ -2,8 +2,8 @@ sp_tables_i <- tibble::tribble(~table_num, ~report_num, ~id,   ~table_code,   ~d
                                100,         51,         "budget-local", "finm_budget", "finm",      "FINM201",    "Pln\\u011bn\\u00ed rozpo\\u010dtu m\\u00edstn\\u011b \\u0159\\u00edzen\\u00fdch organizac\\u00ed" , NA,
                                100,         51,         "budget-local-purpose-grants", "finm_ucel",   "finm",      "FINM207",    "\\u00da\\u010delov\\u00e9 financov\\u00e1n\\u00ed m\\u00edstn\\u011b \\u0159\\u00edzen\\u00fdch organizac\\u00ed", NA,
                                0,           0,          "budget-indicators",     "misris_zu",   "misris",    "((MIS-RIS-ZU)|(ZU-MIS-RIS))", "Z\\u00e1vazn\\u00e9 ukazatele st\\u00e1tn\\u00edho rozpo\\u010dtu", "only central orgs",
-                               0,           0,          "profit-and-loss",     "vykzz",       "vykzz",     "VYKZZ",      "V\\u00fdkaz zisk\\u016f a ztr\\u00e1t" , NA,
-                               0,           0,          "profit-and-loss-city-districts",     "vykzzmc",       "vykzz",     "VYKZZMC",      "V\\u00fdkaz zisk\\u016f a ztr\\u00e1t - m\\u011bstsk\\u00e9 \\u010d\\u00e1sti", "only for 2018; in other years city districts are incorporated in balance sheet",
+                               0,           0,          "profit-and-loss",     "vykzz",       "vykzz",     "VYKZZ1?",      "V\\u00fdkaz zisk\\u016f a ztr\\u00e1t" , NA,
+                               0,           0,          "profit-and-loss-city-districts",     "vykzzmc",       "vykzz",     "VYKZZ_?MC",      "V\\u00fdkaz zisk\\u016f a ztr\\u00e1t - m\\u011bstsk\\u00e9 \\u010d\\u00e1sti", "only for 2018; in other years city districts are incorporated in balance sheet",
                                0,           0,          "changes-in-equity",  "pozvk", "pozvk", "POZVK", "P\\u0159ehled o zm\\u011bn\\u00e1ch vlastn\\u00edho kapit\\u00e1lu", NA,
                                0,           0,          "cash-flow",  "ppt", "ppt", "PPT", "P\\u0159ehled pen\\u011b\\u017en\\u00edch tok\\u016f", NA,
                                0,           0,          "balance-sheet",     "rozvaha1",    "rozv",      "ROZV[1]?",      "Rozvaha - prvn\\u00ed \\u010d\\u00e1st", NA,
@@ -13,7 +13,12 @@ sp_tables_i <- tibble::tribble(~table_num, ~report_num, ~id,   ~table_code,   ~d
                                0,           0,          "budget-central-old",     "finu_budget",  "finu",      "FINU101",    "Pln\\u011bn\\u00ed rozpo\\u010dtu \\u00fast\\u0159edn\\u011b \\u0159\\u00edzen\\u00fdch organizac\\u00ed do 2014", "pre-2015 only",
                                0,           0,          "budget-central-old-purpose-grants",     "finu_ucel",  "finu",      "FINU107",   "\\u00da\\u010delov\\u00e9 financov\\u00e1n\\u00ed - poskytnut\\u00e9 prost\\u0159edky", "pre-2015 only",
                                0,           0,          "budget-central-old-subsidies",     "finu_dotace",  "finu",      "FINU108",    "Dota\\u010dn\\u00ed financov\\u00e1n\\u00ed - poskytnut\\u00e9 prost\\u0159edky", "pre-2015 only",
-                               0,           0,          "budget-central",     "misris",      "misris",    "/MIS-RIS",    "Pln\\u011bn\\u00ed rozpo\\u010dtu \\u00fast\\u0159edn\\u011b \\u0159\\u00edzen\\u00fdch organizac\\u00ed od 2015", "post-2015 only") %>%
+                               0,           0,          "budget-central",     "misris",      "misris",    "/MIS-RIS",    "Pln\\u011bn\\u00ed rozpo\\u010dtu \\u00fast\\u0159edn\\u011b \\u0159\\u00edzen\\u00fdch organizac\\u00ed od 2015", "post-2014 only",
+                               0,           0,          "budget-statefunds",     "finsf_budget",      "finsf",    "FINSF01",    "Pln\\u011bn\\u00ed rozpo\\u010dtu st\\u00e1tn\\u00edch fond\\u016f (\\u010c\\u00e1st I a II: p\\u0159\\u00edjmy a v\\u00fddaje)", "post-2014 only",
+                               0,           0,          "profit-and-loss-statefunds",     "finsf_vykzz",      "finsf",    "FINSF02",    "Pln\\u011bn\\u00ed rozpo\\u010dtu st\\u00e1tn\\u00edch fond\\u016f (\\u010c\\u00e1st III: v\\u00fdkaz zisk\\u016f a ztr\\u00e1t)", "post-2014 only",
+                               0,           0,          "cash-flow-statefunds",     "finsf_cashflow",      "finsf",    "FINSF03",    "Pln\\u011bn\\u00ed rozpo\\u010dtu st\\u00e1tn\\u00edch fond\\u016f (\\u010c\\u00e1st IV: p\\u0159ehled pen\\u011b\\u017en\\u00edch tok\\u016f)", "post-2014 only",
+                               0,           0,          "budget-statefunds-purposegrants",     "finsf_ucel",      "finsf",    "FINSF04",    "Pln\\u011bn\\u00ed rozpo\\u010dtu st\\u00e1tn\\u00edch fond\\u016f (\\u010c\\u00e1st IX: dota\\u010dn\\u00ed financov\\u00e1n\\u00ed - poskytnut\\u00e9 prost\\u0159edky)", "post-2014 only"
+                               ) %>%
   dplyr::mutate_if(is.double, as.integer) %>%
   dplyr::arrange(.data$id)
 # stringi::stri_escape_unicode("xxx")
@@ -33,8 +38,7 @@ sp_tables_i <- tibble::tribble(~table_num, ~report_num, ~id,   ~table_code,   ~d
 #'   \item{\code{note}}{character Note.}
 #' }
 #' @family Lists of available entities
-"sp_tables" <- sp_tables_i %>% dplyr::select(.data$id, .data$dataset_id,
-                                             .data$czech_name, .data$note) %>%
+"sp_tables" <- sp_tables_i %>% dplyr::select("id", "dataset_id", "czech_name", "note") %>%
   dplyr::mutate_if(is.character, stringi::stri_unescape_unicode)
 # usethis::use_data(sp_tables, overwrite = TRUE)
 
@@ -61,7 +65,6 @@ sp_get_table_file <- function(table_id, dataset_path, reunzip = FALSE) {
   dd <- dirname(dataset_path)
   dslist <- list.files(dd, pattern = "*.CSV|*.csv", full.names = T)
   if(length(dslist) == 0 | reunzip) {
-    usethis::ui_info("Unzipping...")
     dslist <- utils::unzip(dataset_path, exdir = dd)
   }
 
@@ -71,11 +74,11 @@ sp_get_table_file <- function(table_id, dataset_path, reunzip = FALSE) {
                                            paste0(table_regex, "(_[0-9]*)?\\.(csv|CSV)"))]
   if(length(table_file) != 1) {
     if (length(table_file) > 1) {
-      ui_stop(c("More than one CSV files in the archive match.",
-                         "You might want to report a bug at {ui_path('https://github.com/petrbouchal/statnipokladna/issues')}."))
+      cli::cli_abort(c(x = "More than one CSV files in the archive match.",
+                       i = "You might want to report a bug at {.url https://github.com/petrbouchal/statnipokladna/issues}."))
     }  else {
-      ui_stop(c("No CSV file inside the downloaded archive matches files needed for the table.",
-                         "You might want to report a bug at {ui_path('https://github.com/petrbouchal/statnipokladna/issues')}."))
+      cli::cli_abort(c(x = "No CSV file inside the downloaded archive matches files needed for the table.",
+                       i = "You might want to report a bug at {.url https://github.com/petrbouchal/statnipokladna/issues}."))
     }
   }
   return(table_file)
@@ -101,11 +104,9 @@ sp_get_table_file <- function(table_id, dataset_path, reunzip = FALSE) {
 #' @export
 sp_load_table <- function(path, ico = NULL) {
 
-  ui_info("Reading data...")
   suppressWarnings(suppressMessages(
     dt <- readr::read_csv2(path, col_types = readr::cols(.default = readr::col_character()))))
   # print(head(dt))
-  ui_info("Transforming data...")
   if(max(stringr::str_length(dt$`ZC_ICO:ZC_ICO`), na.rm = TRUE) == 10) {
     dt <- dplyr::mutate(dt, `ZC_ICO:ZC_ICO` = stringr::str_sub(.data$`ZC_ICO:ZC_ICO`, 3, 10))
   }
@@ -114,10 +115,10 @@ sp_load_table <- function(path, ico = NULL) {
     purrr::set_names(stringr::str_remove(names(dt), "^[A-Z_0-9/]*:")) %>%
     dplyr::mutate_at(dplyr::vars(dplyr::starts_with("ZU_")), ~switch_minus(.) %>% as.numeric(.)) %>%
     tidyr::extract(.data$`0FISCPER`, c("vykaz_year", "vykaz_month"), "([0-9]{4})0([0-9]{2})") %>%
+    dplyr::mutate_at(dplyr::vars(dplyr::ends_with("_date")), lubridate::dmy) %>%
     dplyr::mutate(vykaz_date = lubridate::make_date(.data$vykaz_year, .data$vykaz_month),
                   vykaz_date = lubridate::make_date(.data$vykaz_year, .data$vykaz_month,
                                                       lubridate::days_in_month(.data$vykaz_date))) %>%
-    dplyr::mutate_at(dplyr::vars(dplyr::ends_with("_date")), lubridate::dmy) %>%
     dplyr::rename_all(dplyr::recode,
                       ZCMMT_ITM = "polozka",
                       ZC_VYKAZ = "vykaz",
@@ -151,6 +152,7 @@ sp_load_table <- function(path, ico = NULL) {
                       ZU_ROZPZM = "budget_amended",
                       ZU_KROZP = "budget_final",
                       ZU_ROZKZ = "budget_spending",
+                      ZU_ROZKZM = "budget_spending",
                       ZU_OBLIG = "budget_oblig",
                       ZU_STAVP = "before",
                       ZU_STAVPO = "after",
@@ -206,7 +208,7 @@ sp_load_table <- function(path, ico = NULL) {
 #'  | 0CI_TYPE | polozka_type | item/line type  |  typ položky | - |
 #'  | FUNC0AREA | paragraf |  sector line | paragraf (odvětvové členění)  |  - |
 #'  | ZC_PVS | pvs | programme code | programové výdaje státu | post-2014 |
-#'  | ZC_EDS | eds | subsidy and proprty evidence | Evidenční dotační systém / správa majetku ve vlastnictví státu | post-2014, No codelist - perhaps external via http://www.edssmvs.cz/DocumentsList.aspx?Agenda=CEIS |
+#'  | ZC_EDS | eds | subsidy and proprty evidence | Evidenční dotační systém / správa majetku ve vlastnictví státu | post-2014, No codelist - perhaps external via https://www.edssmvs.cz/DocumentsList.aspx?Agenda=CEIS |
 #'  | ZC_UCRIS | ucris | purpose | Účel | post-2014, no codelist found |
 #'  | 0FUNC_AREA | paragraf |  sector line | paragraf (odvětvové členění)  |  - |
 #'  | ZU_ROZSCH | budget_adopted |  budget as originally adopted | schválený rozpočet  |  - |
@@ -270,11 +272,13 @@ sp_load_table <- function(path, ico = NULL) {
 #' @param year year, numeric, 2015-2019 for some datasets, 2010-2020 for others.
 #' Can be a vector of length > 1 (see Details for how to work with data across time periods.).
 #' @param month month, numeric. Must be 3, 6, 9 or 12. Can be a vector of length > 1 (see details).
-#' @param ico ID(s) of org to return, character of length one or more. If unset, returns all orgs. ID not checked for correctness/existence. See <http://monitor.statnipokladna.cz/datovy-katalog/prohlizec-ciselniku/ucjed> to look up ID of any org in the dataset.
+#' @param ico ID(s) of org to return, character of length one or more. If unset, returns all orgs. ID not checked for correctness/existence. See <https://monitor.statnipokladna.cz/datovy-katalog/prohlizec-ciselniku/ucjed> to look up ID of any org in the dataset.
 #' @param dest_dir character. Directory in which downloaded files will be stored.
 #' If left unset, will use the `statnipokladna.dest_dir` option if the option is set, and `tempdir()` otherwise. Will be created if it does not exist.
 #' @param redownload Redownload even if recent file present? Defaults to FALSE.
 #'
+#' @keywords internal
+#'
 #' @return a [tibble][tibble::tibble-package]; see Details for key to the columns
 #' @encoding UTF-8
 #' @examples
@@ -292,20 +296,19 @@ sp_get_table <- function(table_id, year, month = 12, ico = NULL,
   stopifnot(is.character(ico) | is.null(ico))
   if(interactive() == FALSE & (missing(year) | missing(month))) {
     if(missing(year)) {
-      ui_stop("{ui_field('year')} not set. Please set a value.")
+      cli::cli_abort(c(x = "{.var year} not set. Please set a value."))
 
     } else if(missing(month)) {
-      ui_warn("{ui_field('month')} not set. Using default of {ui_value(month)}.")
+      cli::cli_alert_warning("{.var month} not set. Using default of {.value {month}}.")
 
     }
-
-    ui_todo("Set period parameters explicitly for reproducibility.")
+    if(!interactive()) cli::cli_inform("Set period parameters explicitly for reproducibility.")
   }
 
   if(is.null(dest_dir)) dest_dir <- getOption("statnipokladna.dest_dir",
                                               default = tempdir())
 
-  if(!(table_id %in% sp_tables_i$id)) ui_stop("Not a valid table id. Consult {ui_code('sp_tables')}.")
+  if(!(table_id %in% sp_tables_i$id)) cli::cli_abort("Not a valid table id. Consult {.code sp_tables}.")
   dataset_id <- sp_tables_i$dataset_id[sp_tables_i$id == table_id]
 
   downloaded_datasets <- sp_get_dataset(dataset_id, year, month, dest_dir, redownload)
@@ -328,10 +331,12 @@ sp_get_table <- function(table_id, year, month = 12, ico = NULL,
 #' Deprecated: Get a statnipokladna table\cr\cr
 #' Deprecated, use `sp_get_table()` instead.
 #'
-#' \lifecycle{deprecated}
+#' `r lifecycle::badge("deprecated")`
 #'
 #' @inheritParams sp_get_table
 #'
+#' @keywords internal
+#'
 #' @return a [tibble][tibble::tibble-package]
 #' @export
 get_table <- function(table_id, year, month = 12, ico = NULL,
