@@ -11,14 +11,15 @@ test_that("get_dataset breaks on nonsense", {
 })
 
 check_dataset_error <- function(dataset, year, month) {
-  url <- get_dataset_url(dataset, year, month)
+  url <- sp_get_dataset_url(dataset, year, month)
 }
 
 test_that("select downloads exist", {
   skip_on_cran()
   expect_type(purrr::map_chr(sp_datasets$id[sp_datasets$id != "finu"],
-                             get_dataset_url), type = "character")
-  expect_type(get_dataset_url("finm", 2012, "12"), "character")
-  expect_error(get_dataset_url("finu")) # default dates should not work
-  expect_error(get_dataset_url("x"))
+                             sp_get_dataset_url, year = 2015, month = 12),
+              type = "character")
+  expect_type(sp_get_dataset_url("finm", 2015, "12"), "character")
+  expect_error(sp_get_dataset_url("finu")) # default dates should not work
+  expect_error(sp_get_dataset_url("x"))
 })
